pub struct TypeDefArray {
pub len: u32,
pub type_param: TypeRef,
}Fields
len: u32type_param: TypeRefTrait Implementations
Sourceimpl Clone for TypeDefArray
impl Clone for TypeDefArray
Sourcefn clone(&self) -> TypeDefArray
fn clone(&self) -> TypeDefArray
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TypeDefArray
impl Debug for TypeDefArray
Sourceimpl Encode for TypeDefArray
impl Encode for TypeDefArray
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
Sourceimpl Ord for TypeDefArray
impl Ord for TypeDefArray
Sourcefn cmp(&self, other: &TypeDefArray) -> Ordering
fn cmp(&self, other: &TypeDefArray) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TypeDefArray
impl PartialEq for TypeDefArray
Sourceimpl PartialOrd for TypeDefArray
impl PartialOrd for TypeDefArray
impl EncodeLike for TypeDefArray
impl Eq for TypeDefArray
impl StructuralPartialEq for TypeDefArray