pub struct TypeDefBitSequence {
pub num_bytes: u8,
pub least_significant_bit_first: bool,
}Fields
num_bytes: u8least_significant_bit_first: boolTrait Implementations
Sourceimpl Clone for TypeDefBitSequence
impl Clone for TypeDefBitSequence
Sourcefn clone(&self) -> TypeDefBitSequence
fn clone(&self) -> TypeDefBitSequence
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TypeDefBitSequence
impl Debug for TypeDefBitSequence
Sourceimpl Encode for TypeDefBitSequence
impl Encode for TypeDefBitSequence
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
Sourceimpl Ord for TypeDefBitSequence
impl Ord for TypeDefBitSequence
Sourcefn cmp(&self, other: &TypeDefBitSequence) -> Ordering
fn cmp(&self, other: &TypeDefBitSequence) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TypeDefBitSequence
impl PartialEq for TypeDefBitSequence
Sourceimpl PartialOrd for TypeDefBitSequence
impl PartialOrd for TypeDefBitSequence
impl EncodeLike for TypeDefBitSequence
impl Eq for TypeDefBitSequence
impl StructuralPartialEq for TypeDefBitSequence